@@ -8,7 +8,9 @@ use v5.6;
 use strict;
 use warnings;
 
-our $VERSION = 'v3.1.1';
+# RECOMMEND PREREQ: Graphics::ColorNames
+
+our $VERSION = 'v3.1.2';
 
 sub NamesRgbTable() {
     use integer;
@@ -130,7 +132,7 @@ Graphics::ColorNames::Netscape - Netscape 1.1 Color Names
 
 =head1 VERSION
 
-version v3.1.1
+version v3.1.2
 
 =head1 SYNOPSIS
 
@@ -185,7 +187,7 @@ Robert Rothenberg <rrwo@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Magnus Cedergren Gary Vollink
+=for stopwords Magnus Cedergren Gary Vollink Slaven Rezić
 
 =over 4
 
@@ -197,6 +199,10 @@ Magnus Cedergren <magnus@mbox604.swipnet.se>
 
 Gary Vollink <gary@vollink.com>
 
+=item *
+
+Slaven Rezić <slaven@rezic.de>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
